@@ -5,16 +5,30 @@ use warnings;
 
 use Pod::Usage;
 use Pod::Find qw(pod_where);
+use Getopt::Long qw(GetOptionsFromArray);
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
-my $module_corelist = eval "use Module::CoreList; 1";
+my $module_corelist = eval 'use Module::CoreList; 1';
+my $lwp_useragent   = eval 'use LWP::Simple; 1';
+my $json_any        = eval 'use JSON::Any; 1';
+my $can_do_requests = $lwp_useragent && $json_any;
 
 sub run {
-    @_ or usage();
-    usage(2) if $_[0] eq '-h' or $_[0] eq '--help';
+    GetOptionsFromArray(
+        \@_,
+        \my %opts,
+        'help|h',
+        'no-internet|n',
+    );
+    my @modules = grep { not /^-/ } @_;
 
-    mver($_) for @_;
+    @modules or usage();
+    usage(2) if $opts{help};
+
+    $can_do_requests = 0 if $opts{'no-internet'};
+
+    mver($_) for @modules;
 }
 
 sub mver {
@@ -27,7 +41,7 @@ sub mver {
         print $Config::Config{version};
     }
     else {
-        my $is_loaded = eval "use $arg;1";
+        my $is_loaded = eval "use $arg; 1";
         unless(defined $is_loaded) {
             if($@ =~ /^Can't locate/) {
                 print 'not installed';
@@ -53,6 +67,18 @@ sub mver {
             else {
                 print 'installed, but $VERSION is not defined';
             }
+
+            if($can_do_requests) {
+                my $latest = get_latest_version($arg);
+                if(defined $latest) {
+                    if($latest eq $version) {
+                        print ' (latest)';
+                    }
+                    else {
+                        print " (latest: $latest)";
+                    }
+                }
+            }
         }
     }
     print $/;
@@ -66,6 +92,19 @@ sub is_core {
     !!$found_in_core;
 }
 
+sub get_latest_version {
+    my $arg = shift;
+
+    my $json     = LWP::Simple::get("http://api.metacpan.org/module/$arg") or return;
+    my $response = eval { JSON::Any->from_json($json) } or return;
+
+    if($response->{status} eq 'latest') {
+        return $response->{version};
+    }
+
+    return;
+}
+
 sub usage {
     pod2usage(
         -verbose => $_[0],
@@ -82,7 +121,7 @@ __END__
 
 =head1 NAME
 
-App::Mver - just print modules' $VERSION
+App::Mver - just print modules' C<$VERSION> (and some other stuff)
 
 =head1 DESCRIPTION
 
@@ -94,7 +133,21 @@ For those, who are sick of
 
     mver Module::Name1 Module-Name2 Module::NameN
 
-    mver perl
+    mver perl # shortcut for perl -V:version
+
+=head1 OPTIONS
+
+=over 4
+
+=item --no-internet (-n)
+
+Disable MetaCPAN API querying.
+
+=item --help (-h)
+
+Show this message.
+
+=back
 
 =head1 AUTHOR
 
